@@ -1,12 +1,15 @@
-from aws_cdk import (
-    core,
-    aws_apigateway as _apigateway,
-)
-from aws_cdk.core import Tags
-from aws_cdk_constructs.utils import normalize_environment_parameter
+import aws_cdk as cdk
+from constructs import Construct
+from aws_cdk import aws_apigateway as _apigateway
 
-class API(core.Construct):
-    """Constuct to create API gateway
+from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
+
+class API(Construct):
+    """
+
+    The FAO CDK API Construct creates an AWS API Gateway REST API, providing a Swagger JSON file.
+    
+    Every resource created by the construct will be tagged according to the FAO AWS tagging strategy described at https://aws.fao.org
 
     Args:
 
@@ -23,7 +26,7 @@ class API(core.Construct):
     """
     def __init__(
         self,
-        scope: core.Construct,
+        scope: Construct,
         id: str,
         app_name,
         environment, 
@@ -35,8 +38,13 @@ class API(core.Construct):
         environment = normalize_environment_parameter(environment)
 
         # Apply mandatory tags
-        Tags.of(self).add("ApplicationName", app_name.lower().strip())
-        Tags.of(self).add("Environment", environment)
+        cdk.Tags.of(self).add("ApplicationName", app_name.lower().strip())
+        cdk.Tags.of(self).add("Environment", environment)
+
+        # Apply FAO CDK tags
+        cdk.Tags.of(self).add("fao-cdk-construct", "api")
+        cdk.Tags.of(cdk.Stack.of(self)).add("fao-cdk-version", get_version())
+        cdk.Tags.of(cdk.Stack.of(self)).add("fao-cdk", "true")
         
         # Declare variables
         self.api = None
