@@ -5,6 +5,7 @@ from aws_cdk import (
     aws_ec2 as _ec2,
     aws_kms as _kms,
     aws_route53 as route53,
+    aws_cloudwatch as _cloudwatch,
     aws_route53_targets as route53_targets,
 )
 from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
@@ -13,7 +14,7 @@ engine_to_cdk_engine = {
     "legacy-aurora-mysql": _rds.DatabaseClusterEngine.aurora,
     "aurora-mysql": _rds.DatabaseClusterEngine.aurora_mysql,
     "aurora-postgresql": _rds.DatabaseClusterEngine.aurora_postgres,
-    "aurora-postgresql_12": _rds.DatabaseClusterEngine.aurora_postgres,
+    "aurora-postgresql-12": _rds.DatabaseClusterEngine.aurora_postgres,
     "oracle_s2": _rds.DatabaseInstanceEngine.oracle_se2,
     "oracle_ee": _rds.DatabaseInstanceEngine.oracle_ee,
     "mysql": _rds.DatabaseInstanceEngine.mysql,
@@ -26,11 +27,12 @@ engine_to_cluster_parameter_group_family = {
     "legacy-aurora-mysql": "default.aurora5.6",
     "aurora-mysql": "default.aurora-mysql5.7",
     "aurora-postgresql": "default.aurora-postgresql9.6",
-    "aurora-postgresql_12": "default.aurora-postgresql12",
+    "aurora-postgresql-12": "default.aurora-postgresql12",
     "oracle_s2": "default.oracle-se2-19",
     "oracle_ee": "default.oracle-ee-19",
     "mysql": "default.mysql5.7",
     "postgresql" : None,
+    "sqlserver-se": "default.sqlserver-se-14.0",
     "sqlserver-ex": "default.sqlserver-ex-14.0",
 }
 
@@ -41,7 +43,7 @@ engine_to_version_class = {
     "oracle_s2": _rds.OracleEngineVersion,
     "oracle_ee": _rds.OracleEngineVersion,
     "aurora-postgresql": _rds.AuroraPostgresEngineVersion,
-    "aurora-postgresql_12": _rds.AuroraPostgresEngineVersion,
+    "aurora-postgresql-12": _rds.AuroraPostgresEngineVersion,
     "postgresql": _rds.PostgresEngineVersion,
     "sqlserver-se":  _rds.SqlServerEngineVersion,
     "sqlserver-ex":  _rds.SqlServerEngineVersion,
@@ -49,8 +51,31 @@ engine_to_version_class = {
 
 class Database(Construct):
     """
-    A CDK construct to create a "database tier" for your system.
-    The construct will make easy to develop a fully compliant database component that includes RDS cluster or instance.
+    The FAO CDK Database Construct is used to create RDS databases.
+
+    The construct automatically enables the following main features:
+
+    -	Compatible with every RDS engine and version;
+    -	Create a pre-populated database from RDS snapshots;
+    -	Implement High Availability for production databases;
+    -	Enable access to the FAO SMTP servers if the databases need to send email notifications (additional configuration at the database level may be required);
+    -	Automatic backups and retention configuration according to FAO standards;
+    -	Access from the Production Control bastion host server;
+    -	Database admin user created using AWS Secret Manager, with password rotation enabled every 30 days;
+    -	Encryption at rest of the database storage;
+    -	Default or custom RDS parameter group setup;
+    -	Adoption of the official database naming convention defined by the CSI database admin team;
+    -	Conditionally configure the database removal policy depending on the environment in which the construct is deployed. The policy will be set as `RETAIN` for the Production environment, otherwise set to `DESTROY`;
+    -	Conditionally enablement of the deletion protection setup for Production databases;
+    -	Private DNS record creation for non-Production environments;
+    -	Native integration with the FAO Instance Scheduler to automatically control the uptime of the database;
+    -	Conditionally set the license model of Oracle databases;
+    -	Enable access from Oracle OEM for Oracle database;
+    -	Conditionally export Audit logs to CloudWatch;
+    -	Conditionally grant permission to export data to a specified AWS S3 Bucket;
+    -	Conditionally tracking of database metrics in the FAO CloudWatch dashboard;
+
+    Every resource created by the construct will be tagged according to the FAO AWS tagging strategy described at https://aws.fao.org
 
     Args:
 
@@ -186,6 +211,10 @@ class Database(Construct):
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
+        self.scope = scope
+        self.app_name = app_name
+        self._id = id
+        self.dashboard = None
         environment = normalize_environment_parameter(environment)
         app_name = app_name.lower().strip()
 
@@ -278,7 +307,7 @@ class Database(Construct):
             self,
             "rds_sg",
             vpc=vpc,
-            security_group_name=app_name + "rds_sg",
+            security_group_name=app_name + self._id + "rds_sg",
             allow_all_outbound=True,
         )
 
@@ -562,3 +591,66 @@ class Database(Construct):
 
                 if tag_scheduler_uptime_days:
                     cdk.Tags.of(instance).add("SchedulerUptimeDays", tag_scheduler_uptime_days) 
+
+
+    def _get_dashboard(self) -> _cloudwatch.Dashboard:
+        path = "_".join(self.node.path.split("/")[:-1])
+        return (
+            self.scope.node.try_find_child(f"{self.app_name}-{path}-dashboard")
+            or self._create_dashboard()
+        )
+
+    def _create_dashboard(self) -> _cloudwatch.Dashboard:
+        path = "_".join(self.node.path.split("/")[:-1])
+        return _cloudwatch.Dashboard(
+            self.scope,
+            f"{self.app_name}-{path}-dashboard",
+            dashboard_name=f"{self.app_name}-{path}",
+            end="end",
+            period_override=_cloudwatch.PeriodOverride.AUTO,
+            start="start",
+        )
+
+    def render_widgets(self) -> None:
+        path = "_".join(self.node.path.split("/")[:-1])
+        self.dashboard = self._get_dashboard()
+
+        if self._cluster:
+            self.dashboard.add_widgets(
+                _cloudwatch.TextWidget(markdown=f"# {self._id} {path}", width=24),
+                _cloudwatch.GraphWidget(
+                    left=[self._cluster.metric_cpu_utilization()],
+                    title="CPU Utilization",
+                ),
+                _cloudwatch.GraphWidget(
+                    left=[self._cluster.metric_database_connections()],
+                    title="DB connections",
+                ),
+                _cloudwatch.GraphWidget(
+                    left=[self._cluster.metric_free_local_storage()],
+                    title="Free local storage",
+                ),
+                _cloudwatch.GraphWidget(
+                    left=[
+                        self._cluster.metric_network_receive_throughput(),
+                        self._cluster.metric_network_transmit_throughput(),
+                    ],
+                    title="Network throughput",
+                ),
+            )
+        else:
+            self.dashboard.add_widgets(
+                _cloudwatch.TextWidget(markdown=f"# {self._id} {path}", width=24),
+                _cloudwatch.GraphWidget(
+                    left=[self._instance.metric_cpu_utilization()],
+                    title="CPU Utilization",
+                ),
+                _cloudwatch.GraphWidget(
+                    left=[self._instance.metric_database_connections()],
+                    title="DB connections",
+                ),
+                _cloudwatch.GraphWidget(
+                    left=[self._instance.metric_free_storage_space()],
+                    title="Free local storage",
+                ),
+            )
