@@ -24,7 +24,23 @@ if TYPE_CHECKING:
 
 
 class ECSMicroservice(Construct):
-    """Represents a microservice in a ECS cluster, this class aggregates all AWS entities that will become a FargateService and TaskDefinition
+    """
+
+    The FAO CDK ECSMicroservice Construct represents a microservice in a CDK ECSCluster; this class aggregates all AWS entities that will become a FargateService and TaskDefinition.
+
+    The construct automatically enables the following main features:
+
+    -	FargateService and TaskDefinition creation, with container image and tag definition, CPU, memory setup, memory limit and CPU limit, entry point, port, health check path, desired count, max and min number of containers, and more;
+    -	Docker image definition from AWS Elastic Registry Service (AWS ECR) or as a local asset;
+    -	Auto Scaling and Self-Healing configuration; 
+    -	Native integration with FAO CDK Load Balancer construct and multiple registrations of microservices as targets of the AWS Application Load Balancer;
+    -	Native integration with FAO CDK EFS construct to create AWS EFS volumes and attach them to containers;
+    -	Native integration with the FAO Instance Scheduler to automatically control the uptime of the ECS tasks;
+    -	Private DNS record creation for non-Production environments;
+    -	Enable access to the FAO SMTP servers if the microservices need to send email notifications (additional configuration at the container level may be required);
+    -	Conditionally tracking of ECS task metrics in the FAO CloudWatch dashboard;
+
+    Every resource created by the construct will be tagged according to the FAO AWS tagging strategy described at https://aws.fao.org
 
     Args:
         scope (Construct): Parent construct
