@@ -16,44 +16,24 @@ from ..utils import normalize_environment_parameter
 
 
 class Alb(Construct):
+    """
+        The FAO CDK Alb Construct creates AWS Application Load Balancer resources.
+
+        The construct automatically enables the following main features:
+
+        -	Creates private and internet-facing AWS Application Load Balancers with custom configurations;
+        -	AWS Application Load Balancer integration with AWS Cognito to only allow authenticated requests;
+        -	HTTP and HTTPS listeners setup;
+        -	SSL configuration using FAO or custom certificates;
+        -	Sticky session setup;
+        -	Azure AppProxy, FAO HQ & private clients, Pulse secure VPN integration for private Load Balancers;
+        -	Load Balancer logs collection;
+        -	AWS Target Group creation and health-check configuration;
+        -	Private DNS record creation for non-Production environments;
+        -	Enable access only from Cloudflare v4 and v6 IP ranges;
+
+        Every resource created by the construct will be tagged according to the FAO AWS tagging strategy described at https://aws.fao.org
 
-    def __init__(
-            self,
-            scope: Construct,
-            id: str,
-            app_name: str,
-            environment: str,
-            environments_parameters: dict,
-            vpc: _ec2.IVpc,
-            access_log_bucket_name: str = 'fao-elb-logs',
-            security_group: _ec2.SecurityGroup = None,
-            upstream_security_group: str = None,
-            internet_facing: bool = False,
-            load_balancer_name: str = None,
-            use_cdn: bool = False,
-            main_component_name: str = None,
-            load_balancer_idle_timeout_in_seconds: int = None,
-            dns_record: str = None,
-            create_dns: str = "True",
-            traffic_port: str = "80",
-            ec2_traffic_port: str = "80",
-            ec2_health_check_path: str = "/",
-            ec2_traffic_protocol: str = _alb.ApplicationProtocol.HTTP,
-            stickiness_cookie_duration_in_hours: str = None,
-            healthy_threshold_count: int = 2,
-            unhealthy_threshold_count: int = 2,
-            interval_in_seconds: int = 6,
-            timeout_in_seconds: int = 5,
-            ssl_certificate_arn: str = None,
-            authorization_endpoint=None,
-            token_endpoint=None,
-            issuer=None,
-            client_id=None,
-            client_secret=None,
-            user_info_endpoint=None,
-            will_create_tg: bool = True,
-    ) -> _alb.ApplicationLoadBalancer:
-        """Create a Load Balancer resource
 
         Args:
             id (str): the logical id of the newly created resource
@@ -123,8 +103,45 @@ class Alb(Construct):
             aws_fao_constructs.load_balancer.alb.Alb.tg: Target Group for the Application Load Balancer aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroup
             aws_fao_constructs.load_balancer.alb.Alb.listener: the Application Load Balancer Listener aws_cdk.aws_elasticloadbalancingv2.ApplicationListener
 
-        """
+    """
 
+    def __init__(
+            self,
+            scope: Construct,
+            id: str,
+            app_name: str,
+            environment: str,
+            environments_parameters: dict,
+            vpc: _ec2.IVpc,
+            access_log_bucket_name: str = 'fao-elb-logs',
+            security_group: _ec2.SecurityGroup = None,
+            upstream_security_group: str = None,
+            internet_facing: bool = False,
+            load_balancer_name: str = None,
+            use_cdn: bool = False,
+            main_component_name: str = None,
+            load_balancer_idle_timeout_in_seconds: int = None,
+            dns_record: str = None,
+            create_dns: str = "True",
+            traffic_port: str = "80",
+            ec2_traffic_port: str = "80",
+            ec2_health_check_path: str = "/",
+            ec2_traffic_protocol: str = _alb.Protocol.HTTP,
+            stickiness_cookie_duration_in_hours: str = None,
+            healthy_threshold_count: int = 2,
+            unhealthy_threshold_count: int = 2,
+            interval_in_seconds: int = 6,
+            timeout_in_seconds: int = 5,
+            ssl_certificate_arn: str = None,
+            authorization_endpoint=None,
+            token_endpoint=None,
+            issuer=None,
+            client_id=None,
+            client_secret=None,
+            user_info_endpoint=None,
+            will_create_tg: bool = True,
+    ) -> _alb.ApplicationLoadBalancer:
+       
         super().__init__(scope, id + "-fao-construct")
 
         environment = normalize_environment_parameter(environment)
@@ -372,7 +389,7 @@ class Alb(Construct):
                    interval_in_seconds: int,
                    timeout_in_seconds: int,
                    unhealthy_threshold_count: int,
-                   protocol: _alb.ApplicationProtocol = _alb.ApplicationProtocol.HTTP,
+                   protocol: _alb.Protocol = _alb.Protocol.HTTP,
                    stickiness_cookie_duration_in_hours: str = None,
                    ) -> _alb.ApplicationTargetGroup:
 
@@ -380,7 +397,7 @@ class Alb(Construct):
             self,
             id + "_alb_tg",
             port=int(ec2_traffic_port),  # Must be a int
-            protocol=protocol,
+            protocol=_alb.ApplicationProtocol.HTTP if protocol == _alb.Protocol.HTTP else _alb.ApplicationProtocol.HTTPS,
             vpc=self.vpc,
             target_type=_alb.TargetType.INSTANCE,
             target_group_name=f"{self.app_name}-{id}-{ec2_traffic_port}".replace("_", "-"),
