@@ -19,8 +19,6 @@ import re
 from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
 from aws_cdk_constructs.load_balancer import Alb, Nlb
 
-alphanumericPattern = pattern = re.compile("\W")
-
 
 def enable_access_from_rubrik_cluster(scope, environments_parameters, security_group):
     rubrik_cloud_cluster_secg_id = "sg-0f80734443f5059b2"
@@ -40,21 +38,30 @@ def enable_access_from_rubrik_cluster(scope, environments_parameters, security_g
 
 
 class Microservice(Construct):
-    """A CDK construct to create a "computational tier" for your system.
-    The construct will make easy to develop a fully compliant macro infrastructure component that includes EC2 instances, served by an Application Load Balancer.
+    """
+    The FAO CDK Microservice Construct creates the infrastructure needed to host an EC2-based workload;
 
-    Internally the construct includes:
+    The construct automatically enables the following main features:
 
-    - Application Load Balancer, configurable to be 'internal' or 'interet-facing' or to integrate with Cognito
-
-    - Load Balancer listeners, configurable to be HTTPS or HTTP
-    
-    - Auto Scaling 
-
-    - Target group
-
-    - Launch configuration
+    -	Creates private and public EC2-based stacks;
+    -	Native integration with FAO CDK Alb, Nlb, EFS, Database constructs, and relative features;
+    -	Conditional Auto-Scaling configuration (depending on the application characteristics) with email notification to the Production Control team;
+    -	Self-Healing configuration;
+    -	Custom User-Data and EC2 environment variables definition;
+    -	Native integration with the FAO Instance Scheduler to automatically control the uptime of the EC2 instances;
+    -	EC2 EBS volumes encryption (root and additional);
+    -	Automatic EBS backups and retention configuration according to FAO standards;
+    -	EC2 Instance profile (IAM Role) creation to integrate with configuration S3 bucket, implemented according to the least-privileges principles;
+    -	Conditional permission definition in the EC2 instance role relative auxiliary S3 bucket, if present;
+    -	Adoption and default configuration of the official FAO-hardened EC2 AMI;
+    -	Rolling update compatibility for application releases with EC2 signal setup;
+    -	Production Control bastion host access;
+    -	IT Security scan tools integration;
+    -	Automatic CloudWatch alerts creations;
+    -	Enable access to the FAO SMTP servers if the microservices need to send email notifications (additional configuration at the application level may be required);
+    -	Conditional access to the FAO LDAP service;
 
+    Every resource created by the construct will be tagged according to the FAO AWS tagging strategy described at [https://aws.fao.org]( https://aws.fao.org).
 
     Args:
         id (str): the logical id of the newly created resource
@@ -410,7 +417,7 @@ class Microservice(Construct):
         s3_assets_bucket_name=None,
         traffic_port=None,
         ec2_traffic_port=None,
-        ec2_traffic_protocol=_alb.ApplicationProtocol.HTTP,
+        ec2_traffic_protocol=_alb.Protocol.HTTP,
         upstream_security_group=None,
         ec2_health_check_path=None,
         user_data_s3_key="user-data.sh",
@@ -540,9 +547,7 @@ class Microservice(Construct):
         has_additional_variables = additional_variables
 
         ROOT_VOLUME_SIZE = 50
-        AUTOSCALING_GROUP_LOGICAL_ID = re.sub(
-            alphanumericPattern, "", "".join([main_component_name, "AutoScalingGroup"])
-        )
+        AUTOSCALING_GROUP_LOGICAL_ID = re.sub('[^0-9a-zA-Z]+', '', "".join([main_component_name, "AutoScalingGroup"]))
 
         use_ldap = (
                 will_use_ldap and isinstance(will_use_ldap, str) and will_use_ldap.lower() == "true"
