@@ -5,7 +5,10 @@ from aws_cdk import aws_iam as _iam
 from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
 
 class ServiceUserForIAC(Construct):
-    """Construct to create the Service User to deploy a stack from a CD/CI pipeline
+    """
+    The FAO CDK ServiceUserForIAC Construct creates an AWS IAM user with permission to deploy a whole infrastructure. The permissions are defined according to the least privileges principle leveraging AWS Tags and resources ARNs filtering.
+
+    Every resource created by the construct will be tagged according to the FAO AWS tagging strategy described at https://aws.fao.org
 
     Args:
         id (str): the logical id of the newly created resource
