@@ -1,5 +1,7 @@
 import os
 import re
+from functools import lru_cache
+
 
 def normalize_environment_parameter (environment):
     environment_lower = environment.lower()
@@ -15,10 +17,13 @@ def normalize_environment_parameter (environment):
 
     return "Development"
 
+@lru_cache(maxsize=1)
 def get_version ():
         # reading pymlconf version (same way sqlalchemy does)
         with open(os.path.join(os.path.dirname(__file__), "__init__.py")) as v_file:
                 package_version = (
                         re.compile(r".*__version__ = '(.*?)'", re.S).match(v_file.read()).group(1)
                 )
-                return package_version
\ No newline at end of file
+                return package_version
+
+
